@@ -1,7 +1,8 @@
 import time
 
 from notecoin.database.base import Base, BaseTable
-from sqlalchemy import Column, Float, Integer, String
+from notecoin.strategy.utils import trade_api
+from sqlalchemy import Column, Float, String
 
 
 class OkexStrategyAutoSeller(Base, BaseTable):
@@ -19,10 +20,10 @@ class OkexStrategyAutoSeller(Base, BaseTable):
         self.coin_id = kwargs.get("coin_id")
         self.price = kwargs.get("price")
         self.count = kwargs.get("count")
-        self.worth = kwargs.get("worth") or kwargs.get("worth")
+        self.worth = kwargs.get("worth")
         self.init_worth = kwargs.get("init_worth") or kwargs.get("worth")
-        self.max_worth = kwargs.get("max_worth") or kwargs.get("worth")
-        self.min_worth = kwargs.get("min_worth") or kwargs.get("worth")
+        self.max_worth = kwargs.get("max_worth") or kwargs.get("init_worth") or kwargs.get("worth")
+        self.min_worth = kwargs.get("min_worth") or kwargs.get("init_worth") or kwargs.get("worth")
         self.updateTime = int(time.time() * 1000)
         super(OkexStrategyAutoSeller, self).__init__(*args, **kwargs)
 
@@ -48,6 +49,12 @@ class OkexStrategyAutoSeller(Base, BaseTable):
             "usdt": round(self.worth, 2)
         }
 
+    def buy(self, worth=50):
+        return trade_api.place_order(instId=self.coin_id, tdMode='cash', side='buy', ordType='market', sz=worth)
+
+    def sell(self):
+        return trade_api.place_order(instId=self.coin_id, tdMode='cash', side='sell', ordType='market', sz=self.count)
+
     @staticmethod
-    def instance(coin_id, price=None, count=None, worth=50):
-        return OkexStrategyAutoSeller(coin_id=coin_id, price=price, count=count, worth=worth)
+    def instance(coin_id, price=None, count=None, worth=None, init_worth=50):
+        return OkexStrategyAutoSeller(coin_id=coin_id, price=price, count=count, worth=worth, init_worth=init_worth)
